# RoleSort


## Enum

* `NAME` (value: `'name'`)

* `CREATED_AT` (value: `'created_at'`)

* `UPDATED_AT` (value: `'updated_at'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


